@@ -14,7 +14,7 @@ use File::Glob qw(:bsd_glob);
 use POSIX qw(strftime);                                                         # http://www.cplusplus.com/reference/ctime/strftime/
 use Data::Dump qw(dump);
 
-our $VERSION = '2017.430';
+our $VERSION = '2017.433';
 
 &saveToS3('DataTableText') if 0;                                                # Save code
 
@@ -90,8 +90,9 @@ sub fileOutOfDate($@)
 #-------------------------------------------------------------------------------
 
 sub filePath(@)                                                                 # File
- {my (@file) = grep {$_} @_;                                                    # Drop empty path entries
-  my $t = join '/', map {s/[\/\\]+\Z//r} @_;
+ {my (@file) = @_;                                                              # File componenets
+  $_ or confess "Missing file component\n" for @file;                           # Check that there are no undefined file components
+  my $t = join '/', map {s/[\/\\]+\Z//r} @file;
   $t
  }
 
@@ -128,7 +129,9 @@ sub containingFolder($)
  }
 
 sub xxx(@)                                                                      # Execute a command
- {my $c = join ' ', @_;                                                         # Command to execute
+ {my @cmd = @_;                                                                 # Command to execute
+  $_ or confess "Missing command component\n" for @cmd;                         # Check that there are no undefined command components
+  my $c = join ' ', @_;                                                         # Command to execute
   say STDERR timeStamp, " ", $c;
   my $r = qx($c 2>&1);
   say STDERR $r;
